Utilities
=========

Useful methods completely decoupled from code specific to **urllib3**.

.. warning:: **urllib3.future** does not depends on :mod:`http.client` whereas urllib3 does.

urllib3.future provides various helper methods which are used with the higher level components
but can also be used independently.

.. automodule:: urllib3.util
    :members:
    :show-inheritance:
